@@ -1,8 +1,8 @@
 package XS::Log;
-#Build  MD5 : zd+uj+XHGbw+rKd1XJmC2Q
-#Build Time : 2025-09-17 16:02:35
-our $VERSION = 1.02;
-our $BUILDDATE = "2025-09-17";  #Build Time: 16:02:35
+#Build  MD5 : R1MY9FhOM6oCh4gZqAS+WA
+#Build Time : 2025-09-18 11:29:52
+our $VERSION = 1.03;
+our $BUILDDATE = "2025-09-18";  #Build Time: 11:29:52
 use strict;
 use warnings;
 use XSLoader;
@@ -10,13 +10,17 @@ require Exporter;
 our @ISA = qw(Exporter);
 
 our @EXPORT_OK = qw(
-    openLog closeLog flushLog
+    openLog closeLog flushLog setLogOptions setLogColor setLogMode setLogTargets setLogLevel
     printNote printBug printInf printWarn printErr printFail printText
     LOG_LEVEL_OFF LOG_LEVEL_FATAL LOG_LEVEL_ERROR LOG_LEVEL_WARN LOG_LEVEL_INFO
     LOG_LEVEL_TRACE LOG_LEVEL_DEBUG LOG_LEVEL_TEXT
     LOG_MODE_CYCLE LOG_MODE_DAILY LOG_MODE_HOURLY
     LOG_TARGET_CONSOLE LOG_TARGET_FILE LOG_TARGET_SYSLOG
 );
+# 定义导出标签 :all
+our %EXPORT_TAGS = (
+    all => \@EXPORT_OK,
+);
 XSLoader::load('XS::Log', $VERSION);
 1;
 
@@ -54,20 +58,24 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
      flush_immediately => 1,
  );
  
- Log::openLog("test.log", \%opt);
+ openLog("test.log", \%opt);
  
- Log::printInf("This is info");
- Log::printWarn("This is warning");
- Log::printErr("This is error");
- Log::printFail("This is fatal");
+ printInf("This is info");
+ printWarn("This is warning");
+ printErr("This is error");
+ #printFail("This is fatal");
+ 
+ setLogColor(0);
+ setLogOptions("show_file_info",1);
+ setLogMode(LOG_LEVEL_DEBUG);		#最高级别，显示所有日志
  
  my $user = "Alice";
  my $val  = 42;
 
- Log::printInf("Hello %s, value=%d", $user, $val);
- Log::printErr("File not found: %s", "/tmp/test.txt");
+ printInf("Hello %s, value=%d", $user, $val);
+ printErr("File not found: %s", "/tmp/test.txt");
  
- Log::closeLog();
+ closeLog();
 
 =head1 常量
 
@@ -115,19 +123,44 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
 
 =head2 closeLog
 
+  closeLog();			#关闭日志文件
+  
 =head2 flushLog
 
-=head2 printInf
+  flushLog();			#flush日志缓存
 
-=head2 printWarn
+=head2 setLogConf 
 
-=head2 printErr
+  setLogOptions($opt_key,$opt_val);	#设置options参数
 
-=head2 printFail
+=head2 setLogUseColor 
 
-=head2 printNote
+  setLogUseColor($bool);		#设置日志颜色，0-无颜色 1-有颜色
 
-=head2 printText
+=head2 setLogTargets
+
+  setLogTargets($target);		#设置日志输出日志模式，LOG_TARGET_CONSOLE/LOG_TARGET_FILE
+ 
+=head2 setLogMode
+ 
+  setLogMode($mode)				#设置日志文件循环模式
+
+=head2 setLogLevel
+ 
+  setLogLevel($level)			#设置日志级别
+
+=head2 日志输出命令
+
+  printInf($msg);
+  printWarn($msg);
+  printErr($msg);
+  printFail($msg);      #注意：谨慎使用，会直接exit退出程序
+  printNote($msg);
+  printText($msg);      #原文输出
+
+支持：%的方式格式化输出:
+
+  printInf("%s\n",$msg);
 
 =cut
 
